==> geographica-longitude-0.1.3.tar.gz: geographica-longitude-0.1.3/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

# get the requirements
with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='geographica-longitude',

    version='0.1.3',

    description='Longitude',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/GeographicaGS/Longitude',

    # Author details
    author='Geographica',
    author_email='pypi@geographica.gs',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],

    # What does your project relate to?
    keywords='carto longitude',

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    install_requires=[required],

)

==> geographica-longitude-0.1.5.tar.gz: geographica-longitude-0.1.5/setup.py <==
# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# get the requirements
with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='geographica-longitude',

    version='0.1.5',

    description='Longitude',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/GeographicaGS/Longitude',

    # Author details
    author='Geographica',
    author_email='pypi@geographica.gs',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],

    # What does your project relate to?
    keywords='carto longitude',

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    install_requires=[required],

)
